==> tecfy_corev2_package-1.1.44.tar.gz: lib/views/components/entity/photo.property.dart <==
part of tecfy_corev2_client_package;

class PhotoProperty extends StatefulWidget {
  final Map<String, dynamic>? fileData;

  /// label string
  final String? label;
  final String? description;

  /// is required
  final bool isRequired;

  /// field id
  final String? fileId;

  /// field id
  final int maxSize;

  // final int maxHeight;
  final double? aspectRatioMax;
  final double? aspectRatioMin;

  /// on changed
  final void Function(dynamic)? onChanged;

  PhotoProperty(
      {this.fileData,
      this.label,
      this.description,
      this.maxSize = 200,
      // this.maxHeight = 200,
      this.aspectRatioMax,
      this.aspectRatioMin,
      this.onChanged,
      this.fileId,
      this.isRequired = false}); //: assert(fileId != null );
  @override
  _PhotoPropertyState createState() => _PhotoPropertyState();
}

class _PhotoPropertyState extends State<PhotoProperty> {
  XFile? _photo;

  _onChosePhoto() async {
    var maxWidth = widget.maxSize;
    // var maxHeight = widget.maxHeight;
    if (maxWidth == 0) maxWidth = 200;
    // if (maxHeight == 0) maxHeight = 200;
    _photo = await ImageService().getImage(

        // maxHeight: maxHeight.toDouble(),
      maxWidth: maxWidth.toDouble(),
      //imageQuality: 100,
        );

    if (_photo != null) {
      AppNavigator.showLoading(context);
      //print('File Length : ${photo.data.length}');
      // show loading and upload the photo
      Uint8List imageData = await _photo!.readAsBytes();
      var decodedImage = await decodeImageFromList(imageData);
      print(decodedImage.width);
      print(decodedImage.height);

      if ((widget.aspectRatioMin == null && widget.aspectRatioMax == null) ||
          ((widget.aspectRatioMin! >=
                  (decodedImage.width / decodedImage.height) &&
              widget.aspectRatioMax! <=
                  (decodedImage.width / decodedImage.height)))) {
        print('Aspect NULL');
        var result = await TecfyBasicApp.apiService.httpPostFile(
            'general/storage/file/fullUrl/admin',
            (await _photo!.readAsBytes()),
            path.basename(_photo!.name));
        Navigator.pop(context);
        if (result.success) {
          widget.onChanged?.call(result.data);
          AppNavigator.showMessage(
              context, 'تم رفع الصورة بنجاح', MessageType.success);
        } else {
          print('XXXXXXXXXXXXXXXXXXXX Image Upload Error: ${result.message}');
          AppNavigator.showMessage(
              context, 'خطأ اثناء رفع الصوره', MessageType.error,
              message: result.message);
          _photo = null;
        }
      } else {
        AppNavigator.pop(context);
        // print('Min = ${widget.aspectRatioMin}  ||| '
        //     'Max = ${widget
        //     .aspectRatioMax}  ||  ${(decodedImage.width / decodedImage
        //     .height)}   ${decodedImage.width}  -- ${decodedImage.height}');
        AppNavigator.showMessage(
            context,
            'يجب أن تكون أقل نسبة لأبعاد '
            'الصورة : ${widget.aspectRatioMin}\n  و أقصي نسبة : ${widget.aspectRatioMax}',
            MessageType.error);
      }

      // if ((decodedImage.width / decodedImage.height) == widget.aspectRatio) {
      //   var result = await TecfyBasicApp.apiService.httpPostFile(
      //       'general/storage/file/fullUrl/admin',
      //       (await _photo!.readAsBytes()),
      //       path.basename(_photo!.name));
      //   Navigator.pop(context);
      //   if (result.success) {
      //     widget.onChanged?.call(result.data);
      //     AppNavigator.showMessage(
      //         context, 'تم رفع الصورة بنجاح', MessageType.success);
      //   } else {
      //     print('XXXXXXXXXXXXXXXXXXXX Image Upload Error: ${result.message}');
      //     AppNavigator.showMessage(
      //         context, 'خطأ اثناء رفع الصوره', MessageType.error,
      //         message: result.message);
      //     _photo = null;
      //   }
      // } else {
      //   _photo = null;
      //   Navigator.pop(context);
      //   AppNavigator.showMessage(
      //       context,
      //       'يجب أن تكون أبعاد الصورة مناسبة '
      //       'لهذه الأبعاد \n'
      //       'العرض : ${widget.maxSize} '
      //       'الطول : ${widget.maxSize / widget.aspectRatio!}',
      //       MessageType.error);
      // }
      //print(result.toString());
    }
    setState(() {});
  }

  @override
  Widget build(BuildContext context) {
    return Padding(
        padding: EdgeInsets.all(10),
        child: Row(
          mainAxisAlignment: MainAxisAlignment.center,
          children: <Widget>[
            GestureDetector(
              onTap: _onChosePhoto,
              child: Tooltip(
                  message: widget.description ?? widget.label ?? '',
                  child: _photo != null
                      ? CircleAvatar(
                          backgroundImage: Image.file(File(_photo!.path)).image,
                          radius: 55.0,
                        )
                      : widget.fileData!['_id'] != null || widget.fileId != null
                          ? CircleAvatar(
                              backgroundImage: ImageService.imageProvider(
                                  widget.fileData != null &&
                                          widget.fileData!['_id'] != null
                                      ? widget.fileData!['_id']
                                      : widget.fileId),
                              radius: 55.0)
                          :
                          // Image.asset('assets/images/profile_pic.png',height: 110.0)
                          Column(
                              children: <Widget>[
                                Icon(Icons.photo_size_select_actual),
                                TecfyText(
                                    '${widget.label ?? 'Select Image'}${widget.isRequired ? '*' : ''}')
                              ],
                            )),
            ),
          ],
        ));
  }
}

==> tecfy_corev2_package-1.1.46.tar.gz: lib/views/components/entity/photo.property.dart <==
part of tecfy_corev2_client_package;

class PhotoProperty extends StatefulWidget {
  final Map<String, dynamic>? fileData;

  /// label string
  final String? label;
  final String? description;

  /// is required
  final bool isRequired;

  /// field id
  final String? fileId;

  /// field id
  final int maxSize;

  // final int maxHeight;
  final double? aspectRatioMax;
  final double? aspectRatioMin;

  /// on changed
  final void Function(dynamic)? onChanged;

  PhotoProperty(
      {this.fileData,
      this.label,
      this.description,
      this.maxSize = 200,
      // this.maxHeight = 200,
      this.aspectRatioMax,
      this.aspectRatioMin,
      this.onChanged,
      this.fileId,
      this.isRequired = false}); //: assert(fileId != null );
  @override
  _PhotoPropertyState createState() => _PhotoPropertyState();
}

class _PhotoPropertyState extends State<PhotoProperty> {
  XFile? _photo;

  _onChosePhoto() async {
    var maxWidth = widget.maxSize;
    // var maxHeight = widget.maxHeight;
    if (maxWidth == 0) maxWidth = 200;
    // if (maxHeight == 0) maxHeight = 200;
    _photo = await ImageService().getImage(

        // maxHeight: maxHeight.toDouble(),
      maxWidth: maxWidth.toDouble(),
      //imageQuality: 100,
        );

    if (_photo != null) {
      AppNavigator.showLoading(context);
      //print('File Length : ${photo.data.length}');
      // show loading and upload the photo
      Uint8List imageData = await _photo!.readAsBytes();
      var decodedImage = await decodeImageFromList(imageData);
      print(decodedImage.width);
      print(decodedImage.height);

      if ((widget.aspectRatioMin == null && widget.aspectRatioMax == null) ||
          ((widget.aspectRatioMin! >=
                  (decodedImage.width / decodedImage.height) &&
              widget.aspectRatioMax! <=
                  (decodedImage.width / decodedImage.height)))) {
        print('Aspect NULL');
        var result = await TecfyBasicApp.apiService.httpPostFile(
            'general/storage/file/fullUrl/admin',
            (await _photo!.readAsBytes()),
            path.basename(_photo!.name));
        Navigator.pop(context);
        if (result.success) {
          widget.onChanged?.call(result.data);
          AppNavigator.showMessage(
              context, 'تم رفع الصورة بنجاح', MessageType.success);
        } else {
          print('XXXXXXXXXXXXXXXXXXXX Image Upload Error: ${result.message}');
          AppNavigator.showMessage(
              context, 'خطأ اثناء رفع الصوره', MessageType.error,
              message: result.message);
          _photo = null;
        }
      } else {
        AppNavigator.pop(context);
        // print('Min = ${widget.aspectRatioMin}  ||| '
        //     'Max = ${widget
        //     .aspectRatioMax}  ||  ${(decodedImage.width / decodedImage
        //     .height)}   ${decodedImage.width}  -- ${decodedImage.height}');
        AppNavigator.showMessage(
            context,
            'يجب أن تكون أقل نسبة لأبعاد '
            'الصورة : ${widget.aspectRatioMin!.toStringAsFixed(2)}\n  و أقصي '
            'نسبة : ${widget.aspectRatioMax!.toStringAsFixed(2)}',
            MessageType.error);
      }

      // if ((decodedImage.width / decodedImage.height) == widget.aspectRatio) {
      //   var result = await TecfyBasicApp.apiService.httpPostFile(
      //       'general/storage/file/fullUrl/admin',
      //       (await _photo!.readAsBytes()),
      //       path.basename(_photo!.name));
      //   Navigator.pop(context);
      //   if (result.success) {
      //     widget.onChanged?.call(result.data);
      //     AppNavigator.showMessage(
      //         context, 'تم رفع الصورة بنجاح', MessageType.success);
      //   } else {
      //     print('XXXXXXXXXXXXXXXXXXXX Image Upload Error: ${result.message}');
      //     AppNavigator.showMessage(
      //         context, 'خطأ اثناء رفع الصوره', MessageType.error,
      //         message: result.message);
      //     _photo = null;
      //   }
      // } else {
      //   _photo = null;
      //   Navigator.pop(context);
      //   AppNavigator.showMessage(
      //       context,
      //       'يجب أن تكون أبعاد الصورة مناسبة '
      //       'لهذه الأبعاد \n'
      //       'العرض : ${widget.maxSize} '
      //       'الطول : ${widget.maxSize / widget.aspectRatio!}',
      //       MessageType.error);
      // }
      //print(result.toString());
    }
    setState(() {});
  }

  @override
  Widget build(BuildContext context) {
    return Padding(
        padding: EdgeInsets.all(10),
        child: Row(
          mainAxisAlignment: MainAxisAlignment.center,
          children: <Widget>[
            GestureDetector(
              onTap: _onChosePhoto,
              child: Tooltip(
                  message: widget.description ?? widget.label ?? '',
                  child: _photo != null
                      ? CircleAvatar(
                          backgroundImage: Image.file(File(_photo!.path)).image,
                          radius: 55.0,
                        )
                      : widget.fileData!['_id'] != null || widget.fileId != null
                          ? CircleAvatar(
                              backgroundImage: ImageService.imageProvider(
                                  widget.fileData != null &&
                                          widget.fileData!['_id'] != null
                                      ? widget.fileData!['_id']
                                      : widget.fileId),
                              radius: 55.0)
                          :
                          // Image.asset('assets/images/profile_pic.png',height: 110.0)
                          Column(
                              children: <Widget>[
                                Icon(Icons.photo_size_select_actual),
                                TecfyText(
                                    '${widget.label ?? 'Select Image'}${widget.isRequired ? '*' : ''}')
                              ],
                            )),
            ),
          ],
        ));
  }
}
